import request from '@/utils/request';
import { BaseResponse } from './type';

export interface GetReportListParams {
  /** 报告人 */
  createBy?: string;
  /** 报告开始时间 */
  'params[beginTime]'?: string;
  /** 报告截止时间 */
  'params[endTime]'?: string;
}

export interface ReportItem {
  id?: string;
  /** 报告内容 */
  reportContent?: string;
  /** 1-保存。2-提交 */
  status?: 1 | 2;
  /** 值班日期 */
  dutyDate?: string;
  /** 报告人 */
  createBy?: string;
  /** 更新时间 */
  updateTime?: string;
}

export interface ReportListResponse extends BaseResponse {
  rows?: ReportItem[];
  total?: number;
}

/** 值班报告列表查询 */
export const getReportList = (params: GetReportListParams) =>
  request<ReportListResponse>('GET', {
    url: '/zhdd/dutyReport/list',
    params: params,
  });

export interface ReporItemParams {
  id?: string;
  reportContent: string;
  /** 1-保存。2-提交 */
  status: 1 | 2;
}

/** 值班报告新增 */
export const postReporItem = (params: ReporItemParams) =>
  request<BaseResponse>('POST', {
    url: '/zhdd/dutyReport',
    data: params,
  });
/** 值班报告修改 */
export const putReporItem = (params: ReporItemParams) =>
  request<BaseResponse>('PUT', {
    url: '/zhdd/dutyReport',
    data: params,
  });

export interface RosterItem {
  id?: number;
  period?: number; // 周期，1-星期一
  empName?: string; // 值班人姓名
}

export interface RosterListResponse extends BaseResponse {
  data: RosterItem[];
}

/** 值班列表查询 */
export const getRosterList = () =>
  request<RosterListResponse>('GET', {
    url: 'zhdd/dutyEmp/list',
  });

/** 修改值班人信息 */
export const putRosterItem = (params: RosterItem) =>
  request<BaseResponse>('PUT', {
    url: '/zhdd/dutyEmp',
    data: params,
  });
