import request from '@/utils/request';
import { UploadFile } from 'element-plus/lib/components/upload/src/upload.type';
import { UploadData } from './common';
import { BaseResponse } from './type';

export interface GetPlanListParams {
  name?: string; // 预案名称
  type?: string; // 预案类型
  createDept?: string; // 归属部门
}

export interface PlanItem {
  id?: string; // 非必须
  name?: string; // 名称
  type?: number; // 类型
  createDept?: string; // 归属部门
  createBy?: string; // 非必须
  createTime?: string; // 非必须
  updateTime?: string; // 非必须 更新时间
  // TODO:// 缺少预案类型
}

export interface PlanListResponse extends BaseResponse {
  rows?: PlanItem[];
  total?: number;
}

/** 预案列表查询 */
export const getPlanList = (params: GetPlanListParams) =>
  request<PlanListResponse>('GET', {
    url: '/zhdd/plan/list',
    params: params,
  });

export interface PlanTask {
  id?: string;
  planId?: string;
  level?: number; // 预案等级
  taskDes?: string; // 任务描述
  taskName?: string; // 任务名称
  createBy?: string;
  createTime?: string;
}
export interface PlanItemDetail extends PlanItem {
  planTasks?: {
    1?: PlanTask[];
    2?: PlanTask[];
    3?: PlanTask[];
    4?: PlanTask[];
  };
  planFiles?: { id?: string; fileName: string; fileUrl: string }[];
}

export interface PlanItemDetailResponse extends BaseResponse {
  data?: PlanItemDetail;
}

/** 获取预案详情 */
export const getPlanItem = (id: string) =>
  request<PlanItemDetailResponse>('GET', {
    url: `/zhdd/plan/${id}`,
  });

export interface PlanItemParams extends PlanItem {
  planTasks?: {
    level: number; // 预案等级
    taskDes: string; // 任务描述
    taskName: string; // 任务名称
  }[];
  planFiles: UploadData[];
}

/** 新增预案 */
export const addPlanItem = (params: PlanItemParams) =>
  request<BaseResponse>('POST', {
    url: '/zhdd/plan',
    data: params,
  });

/** 修改预案 */
export const editPlanItem = (params: PlanItemParams) =>
  request<BaseResponse>('PUT', {
    url: '/zhdd/plan',
    data: params,
  });

/** 删除预案 */
export const deletePlanItem = (ids: string) =>
  request<BaseResponse>('DELETE', {
    url: `/zhdd/plan/${ids}`,
  });

export interface PlanFilePatams {
  planId?: string; // 应急预案id
  planName?: string; // 文件名称
  planUrl?: string; // 文件路径
}

/** 新增应急文件 */
export const addPlanFile = (params: PlanFilePatams) =>
  request<BaseResponse>('POST', {
    url: '/zhdd/plan/file',
    data: params,
  });
